@@ -3,8 +3,8 @@ use strict;
 use warnings;
 use Class::C3;
 
-our $VERSION = '0.01';
-use base 'Catalyst::Model::MultiAdaptor::Base';
+our $VERSION = '0.02';
+use parent 'Catalyst::Model::MultiAdaptor::Base';
 
 sub new {
     my $class = shift;
@@ -108,7 +108,7 @@ Catalyst model.
 
 =head1 AUTHOR
 
-dann E<lt>techmemo@gmail.comE<gt>
+Takatoshi KitanoE<lt>kitano.tk@gmail.comE<gt>
 
 =head1 SEE ALSO
 
